import { useUserStore } from 'stores/user';

import axios from 'axios';
import { useQuasar } from 'quasar';

export function usePrintService() {
    const quasar = useQuasar();
    const { getTokenMultimedia } = useUserStore();

    function sendEmail(path, params) {
        return axios.post(path, params).then(() =>
            quasar.notify({
                message: 'Notification sent',
                type: 'positive',
                icon: 'check'
            })
        );
    }

    function openReport(path, params, isNewTab = '_self') {
        if (typeof params === 'string') params = JSON.parse(params);
        params = Object.assign(
            {
                access_token: getTokenMultimedia()
            },
            params
        );

        const query = new URLSearchParams(params).toString();
        window.open(`api/${path}?${query}`, isNewTab);
    }

    return {
        sendEmail,
        openReport
    };
}
