describe('Photo Uploader Component', () => {
    beforeEach(() => {
        cy.login('developer');
        cy.visit('/#/admin/photos');
    });

    const uploadFile = fileName => {
        cy.get('.q-uploader__input').selectFile(fileName);
    };

    it('should display the photo collection select', () => {
        // Verificar que el select de colección esté presente
        cy.dataCy('photoCollectionSelect').should('exist');
    });

    it('should allow selecting a photo collection', () => {
        // Simular la selección de una colección de fotos
        cy.selectOption('[data-testid="photoCollectionSelect"]', 'Enlace');
        cy.getValue('[data-testid="photoCollectionSelect"]').should(
            'equal',
            'Enlace'
        );
    });

    it('submit button should be disabled if no files are selected', () => {
        cy.dataCy('photoUploadSubmitBtn').should('be.disabled');
    });

    it('should allow adding files', () => {
        cy.dataCy('photoUploaderItem').should('not.exist');
        uploadFile('src/test/cypress/fixtures/lowres.jpg');
        cy.dataCy('photoUploaderItem').should('exist');
        cy.dataCy('photoUploaderItem').should('have.length', 1);
    });

    it('should remove a file when delete button is clicked', () => {
        uploadFile('src/test/cypress/fixtures/lowres.jpg');

        cy.dataCy('photoUploaderItem').should('exist');
        cy.dataCy('photoUploaderItemsDeleteBtn').click();
        cy.dataCy('photoUploaderItem').should('not.exist');
    });

    it('should enable the upload button when files are pending', () => {
        uploadFile('src/test/cypress/fixtures/lowres.jpg');
        cy.dataCy('photoUploadSubmitBtn').should('not.be.disabled');
    });

    it('should upload files when submit button is clicked', () => {
        uploadFile('src/test/cypress/fixtures/lowres.jpg');
        cy.dataCy('photoUploadSubmitBtn').click();
        cy.checkNotify('positive', 'Imágenes subidas correctamente');
    });

    it('should show the correct status icon', () => {
        uploadFile('src/test/cypress/fixtures/lowres.jpg');
        cy.dataCy('photoUploaderItemsStatusIcon').should('have.text', 'add');
        cy.dataCy('photoUploadSubmitBtn').click();
        cy.dataCy('photoUploaderItemsStatusIcon').should(
            'have.text',
            'cloud_done'
        );
    });

    it('should clear all files when clear button is clicked', () => {
        uploadFile('src/test/cypress/fixtures/lowres.jpg');
        cy.dataCy('photoUploaderItem').should('exist');
        cy.dataCy('photoUploaderClearBtn').click();
        cy.dataCy('photoUploaderItem').should('not.exist');
    });

    it('should display error notification if an upload fails', () => {
        uploadFile('src/test/cypress/fixtures/low-res.jpg');
        cy.dataCy('photoUploadSubmitBtn').click();
        cy.checkNotify(
            'negative',
            'Ocurrieron errores al subir alguna de las imágenes'
        );
    });
});
