describe('PendingOrders', () => {
    before(() => {
        // Esto se ejecuta una vez antes de todas las pruebas
        cy.resetDB();
    });

    beforeEach(() => {
        cy.login('developer');
    });

    const checkEmptyList = () => {
        cy.dataCy('pendingOrdersList').should('exist');
        cy.dataCy('pendingOrdersList').should('contain', 'Lista vacía');
        cy.dataCy('pendingOrderCard').should('not.exist');
    };

    const checkExistingOrder = () => {
        cy.dataCy('pendingOrdersList').should('exist');
        cy.dataCy('pendingOrdersList').should('not.contain', 'Lista vacía');
        cy.dataCy('pendingOrderCard').should('exist');
    };

    it('shows empty state', () => {
        // Cuando la db se reinicia el usuario developer no tiene ordenes pendientes
        cy.visit('/#/ecomerce/pending');
        checkEmptyList();
    });

    it('creates a new order', () => {
        cy.createOrderReceiveFlow();
        cy.visit('/#/ecomerce/pending');
        checkExistingOrder();
        cy.dataCy('pendingOrderCard').should('have.length', 1);
        cy.resetDB();
    });

    it('deletes an order', () => {
        cy.createOrderReceiveFlow();
        cy.visit('/#/ecomerce/pending');
        checkExistingOrder();
        cy.dataCy('pendingOrderCard').should('have.length', 1);
        cy.dataCy('pendingOrderCardDelete').click();
        cy.setConfirmDialog();
        cy.checkNotify('positive', 'Datos guardados');
        checkEmptyList();
    });

    it('adds order to basket', () => {
        cy.createOrderReceiveFlow();
        cy.visit('/#/ecomerce/pending');
        cy.dataCy('addOrderToBasket').should('exist');
        cy.dataCy('addOrderToBasket').click();
        cy.checkNotify('positive', '¡Pedido cargado en la cesta!');
    });
});
